@@ -42,15 +42,8 @@ if (getcwd() == dirname(__FILE__)) {
  * Minimum PHP version; can't call PMA_fatalError() which uses a
  * PHP 5 function, so cannot easily localize this message.
  */
-if (version_compare(PHP_VERSION, '5.2.0', 'lt')) {
-    die('PHP 5.2+ is required');
-}
-
-/**
-  * Backward compatibility for PHP 5.2
-  */
-if (!defined('E_DEPRECATED')) {
-    define('E_DEPRECATED', 8192);
+if (version_compare(PHP_VERSION, '5.3.0', 'lt')) {
+    die('PHP 5.3+ is required');
 }
 
 /**
@@ -69,17 +62,6 @@ require './libraries/Error_Handler.class.php';
 $GLOBALS['error_handler'] = new PMA_Error_Handler();
 $cfg['Error_Handler']['display'] = true;
 
-/*
- * This setting was removed in PHP 5.3. But at this point PMA_PHP_INT_VERSION
- * is not yet defined so we use another way to find out the PHP version.
- */
-if (version_compare(phpversion(), '5.3', 'lt')) {
-    /**
-     * Avoid object cloning errors
-     */
-    @ini_set('zend.ze1_compatibility_mode', false);
-}
-
 /**
  * This setting was removed in PHP 5.4. But at this point PMA_PHP_INT_VERSION
  * is not yet defined so we use another way to find out the PHP version.
@@ -88,7 +70,7 @@ if (version_compare(phpversion(), '5.4', 'lt')) {
     /**
      * Avoid problems with magic_quotes_runtime
      */
-    @ini_set('magic_quotes_runtime', false);
+    @ini_set('magic_quotes_runtime', '0');
 }
 
 /**
@@ -143,7 +125,7 @@ require './libraries/Table.class.php';
  */
 require './libraries/Types.class.php';
 
-if (! defined('PMA_MINIMUM_COMMON') || defined('PMA_SETUP')) {
+if (! defined('PMA_MINIMUM_COMMON')) {
     /**
      * common functions
      */
@@ -235,7 +217,7 @@ unset($key, $value, $variables_whitelist);
  * so we now check if a subform is submitted
  */
 $__redirect = null;
-if (isset($_POST['usesubform']) && ! defined('PMA_MINIMUM_COMMON')) {
+if (isset($_POST['usesubform'])) {
     // if a subform is present and should be used
     // the rest of the form is deprecated
     $subform_id = key($_POST['usesubform']);
@@ -265,17 +247,14 @@ if (isset($_POST['usesubform']) && ! defined('PMA_MINIMUM_COMMON')) {
 // end check if a subform is submitted
 
 /**
- * This setting was removed in PHP 5.4. But at this point PMA_PHP_INT_VERSION
- * is not yet defined so we use another way to find out the PHP version.
+ * This setting was removed in PHP 5.4, but get_magic_quotes_gpc
+ * always returns False since then.
  */
-if (version_compare(phpversion(), '5.4', 'lt')) {
-    // remove quotes added by PHP
-    if (function_exists('get_magic_quotes_gpc') && get_magic_quotes_gpc()) {
-        PMA_arrayWalkRecursive($_GET, 'stripslashes', true);
-        PMA_arrayWalkRecursive($_POST, 'stripslashes', true);
-        PMA_arrayWalkRecursive($_COOKIE, 'stripslashes', true);
-        PMA_arrayWalkRecursive($_REQUEST, 'stripslashes', true);
-    }
+if (get_magic_quotes_gpc()) {
+    PMA_arrayWalkRecursive($_GET, 'stripslashes', true);
+    PMA_arrayWalkRecursive($_POST, 'stripslashes', true);
+    PMA_arrayWalkRecursive($_COOKIE, 'stripslashes', true);
+    PMA_arrayWalkRecursive($_REQUEST, 'stripslashes', true);
 }
 
 /**
@@ -346,11 +325,10 @@ if (isset($_COOKIE)
 if ($GLOBALS['PMA_Config']->get('ForceSSL')
     && ! $GLOBALS['PMA_Config']->get('is_https')
 ) {
-    require './libraries/select_lang.lib.php';
     // grab SSL URL
     $url = $GLOBALS['PMA_Config']->getSSLUri();
     // Actually redirect
-    PMA_sendHeaderLocation($url . PMA_generate_common_url($_GET, 'text'));
+    PMA_sendHeaderLocation($url . PMA_URL_getCommon($_GET, 'text'));
     // delete the current session, otherwise we get problems (see bug #2397877)
     $GLOBALS['PMA_Config']->removeCookie($GLOBALS['session_name']);
     exit;
@@ -401,6 +379,7 @@ $goto_whitelist = array(
     'index.php',
     'pdf_pages.php',
     'pdf_schema.php',
+    //'phpinfo.php',
     'querywindow.php',
     'server_binlog.php',
     'server_collations.php',
@@ -482,7 +461,7 @@ if (PMA_checkPageValidity($_REQUEST['back'], $goto_whitelist)) {
  */
 $token_mismatch = true;
 if (PMA_isValid($_REQUEST['token'])) {
-    $token_mismatch = ! hash_equals($_SESSION[' PMA_token '], $_REQUEST['token']);
+    $token_mismatch = ($_SESSION[' PMA_token '] != $_REQUEST['token']);
 }
 
 if ($token_mismatch) {
@@ -500,12 +479,15 @@ if ($token_mismatch) {
         'pma_lang', 'pma_collation_connection',
         /* Possible login form */
         'pma_servername', 'pma_username', 'pma_password',
+        'recaptcha_challenge_field', 'recaptcha_response_field',
         /* Needed to send the correct reply */
         'ajax_request',
         /* Permit to log out even if there is a token mismatch */
         'old_usr',
-        /* url.php */
+        /* Permit redirection with token-mismatch in url.php */
         'url',
+        /* Permit session expiry flag */
+        'session_expired'
     );
     /**
      * Allow changing themes in test/theme.php
@@ -520,7 +502,7 @@ if ($token_mismatch) {
     /**
      * Do actual cleanup
      */
-    PMA_remove_request_vars($allow_list);
+    PMA_removeRequestVars($allow_list);
 
 }
 
@@ -598,7 +580,7 @@ if ($GLOBALS['text_dir'] == 'ltr') {
 $GLOBALS['PMA_Config']->checkPermissions();
 
 if ($GLOBALS['PMA_Config']->error_config_file) {
-    $error = '[strong]' . __('Failed to read configuration file') . '[/strong]'
+    $error = '[strong]' . __('Failed to read configuration file!') . '[/strong]'
         . '[br][br]'
         . __('This usually means there is a syntax error in it, please check any errors shown below.')
         . '[br][br]'
@@ -674,7 +656,7 @@ if (! isset($cfg['Servers']) || count($cfg['Servers']) == 0) {
             && empty($each_server['host'])
             && empty($each_server['verbose'])
         ) {
-            $each_server['verbose'] = __('Server') . $server_index;
+            $each_server['verbose'] = sprintf(__('Server %d'), $server_index);
         }
 
         $new_servers[$server_index] = $each_server;
@@ -759,7 +741,7 @@ if (! defined('PMA_MINIMUM_COMMON')) {
     /**
      * String handling
      */
-    include_once './libraries/string.lib.php';
+    include_once './libraries/string.inc.php';
 
     /**
      * Lookup server by name
@@ -770,7 +752,11 @@ if (! defined('PMA_MINIMUM_COMMON')) {
         && ! is_numeric($_REQUEST['server'])
     ) {
         foreach ($cfg['Servers'] as $i => $server) {
-            if ($server['host'] == $_REQUEST['server']) {
+            if ($server['host'] == $_REQUEST['server']
+                || $server['verbose'] == $_REQUEST['server']
+                || $PMA_String->strtolower($server['verbose']) == $PMA_String->strtolower($_REQUEST['server'])
+                || md5($PMA_String->strtolower($server['verbose'])) == $PMA_String->strtolower($_REQUEST['server'])
+            ) {
                 $_REQUEST['server'] = $i;
                 break;
             }
@@ -836,7 +822,7 @@ if (! defined('PMA_MINIMUM_COMMON')) {
         /**
          * Loads the proper database interface for this server
          */
-        include_once './libraries/database_interface.lib.php';
+        include_once './libraries/database_interface.inc.php';
 
         include_once './libraries/logging.lib.php';
 
@@ -844,8 +830,10 @@ if (! defined('PMA_MINIMUM_COMMON')) {
         // no generic solution for loading preferences from cache as some settings
         // need to be kept for processing in PMA_Config::loadUserPreferences()
         $cache_key = 'server_' . $GLOBALS['server'];
-        if (isset($_SESSION['cache'][$cache_key]['userprefs']['LoginCookieValidity'])) {
-            $value = $_SESSION['cache'][$cache_key]['userprefs']['LoginCookieValidity'];
+        if (isset($_SESSION['cache'][$cache_key]['userprefs']['LoginCookieValidity'])
+        ) {
+            $value
+                = $_SESSION['cache'][$cache_key]['userprefs']['LoginCookieValidity'];
             $GLOBALS['PMA_Config']->set('LoginCookieValidity', $value);
             $GLOBALS['cfg']['LoginCookieValidity'] = $value;
             unset($value);
@@ -862,15 +850,15 @@ if (! defined('PMA_MINIMUM_COMMON')) {
          * the required auth type plugin
          */
         $auth_class = "Authentication" . ucfirst($cfg['Server']['auth_type']);
-        if (! file_exists('./libraries/plugins/auth/' . $auth_class . '.class.php')) {
+        if (! file_exists(
+            './libraries/plugins/auth/'
+            . $auth_class . '.class.php'
+        )) {
             PMA_fatalError(
                 __('Invalid authentication method set in configuration:')
                 . ' ' . $cfg['Server']['auth_type']
             );
         }
-        if (isset($_REQUEST['pma_password'])) {
-            $_REQUEST['pma_password'] = substr($_REQUEST['pma_password'], 0, 256);
-        }
         include_once  './libraries/plugins/auth/' . $auth_class . '.class.php';
         // todo: add plugin manager
         $plugin_manager = null;
@@ -924,22 +912,24 @@ if (! defined('PMA_MINIMUM_COMMON')) {
 
             // Ejects the user if banished
             if ($allowDeny_forbidden) {
-                PMA_log_user($cfg['Server']['user'], 'allow-denied');
+                PMA_logUser($cfg['Server']['user'], 'allow-denied');
                 $auth_plugin->authFails();
             }
         } // end if
 
         // is root allowed?
-        if (!$cfg['Server']['AllowRoot'] && $cfg['Server']['user'] == 'root') {
+        if (! $cfg['Server']['AllowRoot'] && $cfg['Server']['user'] == 'root') {
             $allowDeny_forbidden = true;
-            PMA_log_user($cfg['Server']['user'], 'root-denied');
+            PMA_logUser($cfg['Server']['user'], 'root-denied');
             $auth_plugin->authFails();
         }
 
         // is a login without password allowed?
-        if (!$cfg['Server']['AllowNoPassword'] && $cfg['Server']['password'] == '') {
+        if (! $cfg['Server']['AllowNoPassword']
+            && $cfg['Server']['password'] == ''
+        ) {
             $login_without_password_is_forbidden = true;
-            PMA_log_user($cfg['Server']['user'], 'empty-denied');
+            PMA_logUser($cfg['Server']['user'], 'empty-denied');
             $auth_plugin->authFails();
         }
 
@@ -954,15 +944,34 @@ if (! defined('PMA_MINIMUM_COMMON')) {
         // scripts)
         $controllink = false;
         if ($cfg['Server']['controluser'] != '') {
-            if (! empty($cfg['Server']['controlhost'])) {
-                $controllink = PMA_DBI_connect(
+            if (! empty($cfg['Server']['controlhost'])
+                || ! empty($cfg['Server']['controlport'])
+            ) {
+                $server_details = array();
+                if (! empty($cfg['Server']['controlhost'])) {
+                    $server_details['host'] = $cfg['Server']['controlhost'];
+                } else {
+                    $server_details['host'] = $cfg['Server']['host'];
+                }
+                if (! empty($cfg['Server']['controlport'])) {
+                    $server_details['port'] = $cfg['Server']['controlport'];
+                } elseif ($server_details['host'] == $cfg['Server']['host']) {
+                    // Evaluates to true when controlhost == host
+                    // or controlhost is not defined (hence it defaults to host)
+                    // In such case we can use the value of port.
+                    $server_details['port'] = $cfg['Server']['port'];
+                }
+                // otherwise we leave the $server_details['port'] unset,
+                // allowing it to take default mysql port
+
+                $controllink = $GLOBALS['dbi']->connect(
                     $cfg['Server']['controluser'],
                     $cfg['Server']['controlpass'],
                     true,
-                    array('host' => $cfg['Server']['controlhost'])
+                    $server_details
                 );
             } else {
-                $controllink = PMA_DBI_connect(
+                $controllink = $GLOBALS['dbi']->connect(
                     $cfg['Server']['controluser'],
                     $cfg['Server']['controlpass'],
                     true
@@ -971,7 +980,7 @@ if (! defined('PMA_MINIMUM_COMMON')) {
         }
 
         // Connects to the server (validates user's login)
-        $userlink = PMA_DBI_connect(
+        $userlink = $GLOBALS['dbi']->connect(
             $cfg['Server']['user'], $cfg['Server']['password'], false
         );
 
@@ -979,20 +988,20 @@ if (! defined('PMA_MINIMUM_COMMON')) {
             $controllink = $userlink;
         }
 
-        $auth_plugin->storeUserCredentials();
-
         /* Log success */
-        PMA_log_user($cfg['Server']['user']);
+        PMA_logUser($cfg['Server']['user']);
 
-        /**
-         * with phpMyAdmin 3 we support MySQL >=5
-         * but only production releases:
-         *  - > 5.0.15
-         */
-        if (PMA_MYSQL_INT_VERSION < 50015) {
+        if (PMA_MYSQL_INT_VERSION < 50500) {
             PMA_fatalError(
                 __('You should upgrade to %s %s or later.'),
-                array('MySQL', '5.0.15')
+                array('MySQL', '5.5.0')
+            );
+        }
+
+        if (PMA_PHP_INT_VERSION < 50300) {
+            PMA_fatalError(
+                __('You should upgrade to %s %s or later.'),
+                array('PHP', '5.3.0')
             );
         }
 
@@ -1006,9 +1015,6 @@ if (! defined('PMA_MINIMUM_COMMON')) {
         }
 
         if (PMA_DRIZZLE) {
-            // DisableIS must be set to false for Drizzle, it maps SHOW commands
-            // to INFORMATION_SCHEMA queries anyway so it's fast on large servers
-            $cfg['Server']['DisableIS'] = false;
             // SHOW OPEN TABLES is not supported by Drizzle
             $cfg['SkipLockedTables'] = false;
         }
@@ -1018,11 +1024,6 @@ if (! defined('PMA_MINIMUM_COMMON')) {
          */
         include_once './libraries/sqlparser.lib.php';
 
-        /**
-         * SQL Validator interface code
-         */
-        include_once './libraries/sqlvalidator.lib.php';
-
         /**
          * the PMA_List_Database class
          */
@@ -1034,12 +1035,12 @@ if (! defined('PMA_MINIMUM_COMMON')) {
         /**
          * some resetting has to be done when switching servers
          */
-        if (isset($_SESSION['tmp_user_values']['previous_server'])
-            && $_SESSION['tmp_user_values']['previous_server'] != $GLOBALS['server']
+        if (isset($_SESSION['tmpval']['previous_server'])
+            && $_SESSION['tmpval']['previous_server'] != $GLOBALS['server']
         ) {
-            unset($_SESSION['tmp_user_values']['navi_limit_offset']);
+            unset($_SESSION['tmpval']['navi_limit_offset']);
         }
-        $_SESSION['tmp_user_values']['previous_server'] = $GLOBALS['server'];
+        $_SESSION['tmpval']['previous_server'] = $GLOBALS['server'];
 
     } // end server connecting
 
@@ -1065,13 +1066,11 @@ if (! defined('PMA_MINIMUM_COMMON')) {
     if (isset($_SESSION['profiling'])) {
         $header   = $response->getHeader();
         $scripts  = $header->getScripts();
-        /* < IE 9 doesn't support canvas natively */
-        if (PMA_USR_BROWSER_AGENT == 'IE' && PMA_USR_BROWSER_VER < 9) {
-            $scripts->addFile('canvg/flashcanvas.js');
-        }
         $scripts->addFile('jqplot/jquery.jqplot.js');
         $scripts->addFile('jqplot/plugins/jqplot.pieRenderer.js');
+        $scripts->addFile('jqplot/plugins/jqplot.highlighter.js');
         $scripts->addFile('canvg/canvg.js');
+        $scripts->addFile('jquery/jquery.tablesorter.js');
     }
 
     /*
@@ -1113,18 +1112,6 @@ if (isset($_REQUEST['ajax_request']) && $_REQUEST['ajax_request'] == true) {
     $GLOBALS['is_ajax_request'] = false;
 }
 
-/**
- * @global  boolean $GLOBALS['grid_edit']
- *
- * Set to true if this is a request made during an grid edit process.  This
- * request is made to retrieve the non-truncated/transformed values.
- */
-if (isset($_REQUEST['grid_edit']) && $_REQUEST['grid_edit'] == true) {
-    $GLOBALS['grid_edit'] = true;
-} else {
-    $GLOBALS['grid_edit'] = false;
-}
-
 if (isset($_REQUEST['GLOBALS']) || isset($_FILES['GLOBALS'])) {
     PMA_fatalError(__("GLOBALS overwrite attempt"));
 }
@@ -1149,7 +1136,8 @@ unset($dummy);
 
 // here, the function does not exist with this configuration:
 // $cfg['ServerDefault'] = 0;
-$GLOBALS['is_superuser'] = function_exists('PMA_isSuperuser') && PMA_isSuperuser();
+$GLOBALS['is_superuser']
+    = isset($GLOBALS['dbi']) && $GLOBALS['dbi']->isSuperuser();
 
 if (!empty($__redirect) && in_array($__redirect, $goto_whitelist)) {
     /**
